===========
pymergedocx
===========


.. image:: https://img.shields.io/pypi/v/pymergedocx.svg
:target: https://pypi.python.org/pypi/pymergedocx

.. image:: https://img.shields.io/travis/x-debug/pymergedocx.svg
:target: https://travis-ci.org/x-debug/pymergedocx

.. image:: https://readthedocs.org/projects/pymergedocx/badge/?version=latest
:target: https://pymergedocx.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




    python 下合并doc库,使用非常简单
        merge_docx('{}/files/result.docx'.format(current_path), '{}/files/template.docx'.format(current_path),
            '{}/files/template1.docx'.format(current_path), '{}/files/template2.docx'.format(current_path))


    * Free software: Apache Software License 2.0
    * Documentation: https://pymergedocx.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
